# MCP 配置指南（项目级）

目标：只在项目内提供 MCP 的配置方式与示例片段。

## 原则
- 默认不修改 `~/.config/opencode`。
- 如果用户希望启用 MCP：优先使用项目内 `opencode.jsonc` 的 `mcp` 段落。

## 示例
- 参考：`opencode.jsonc`
- snippets：`.vibe-wf/snippets/mcp/`

## 系统级配置（默认不做）
如果你确实需要修改系统级配置：必须用户明确同意，且先展示 diff。
